aboutsummaryrefslogtreecommitdiff
path: root/plugin.go
diff options
context:
space:
mode:
Diffstat (limited to 'plugin.go')
-rw-r--r--plugin.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/plugin.go b/plugin.go
index c14f700..e634f02 100644
--- a/plugin.go
+++ b/plugin.go
@@ -1,4 +1,4 @@
-package koushin
+package alps
import (
"html/template"
@@ -9,7 +9,7 @@ import (
// PluginDir is the path to the plugins directory.
const PluginDir = "plugins"
// Plugin extends koushin with additional functionality.
type Plugin interface {
// Name should return the plugin name.
Name() string
@@ -9,7 +9,7 @@ import (
// PluginDir is the path to the plugins directory.
const PluginDir = "plugins"
-// Plugin extends koushin with additional functionality.
+// Plugin extends alps with additional functionality.
type Plugin interface {
// Name should return the plugin name.